@@ -1,8 +1,6 @@
 package Moose::Exception::CouldNotGenerateInlineAttributeMethod;
-BEGIN {
-  $Moose::Exception::CouldNotGenerateInlineAttributeMethod::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CouldNotGenerateInlineAttributeMethod::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Instance';
@@ -24,4 +22,5 @@ sub _build_message {
     "Could not generate inline ".$self->option." because : ".$self->error;
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
