@@ -1,8 +1,6 @@
 package Moose::Exception::SingleParamsToNewMustBeHashRef;
-BEGIN {
-  $Moose::Exception::SingleParamsToNewMustBeHashRef::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::SingleParamsToNewMustBeHashRef::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -10,4 +8,5 @@ sub _build_message {
     "Single parameters to new() must be a HASH ref";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
