@@ -1,12 +1,9 @@
 package Moose::Meta::Method::Accessor::Native::Array::first_index;
-BEGIN {
-  $Moose::Meta::Method::Accessor::Native::Array::first_index::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Meta::Method::Accessor::Native::Array::first_index::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use strict;
 use warnings;
 
-use List::MoreUtils ();
 use Params::Util ();
 
 use Moose::Role;
@@ -22,7 +19,7 @@ sub _inline_check_arguments {
 
     return (
         'if (!Params::Util::_CODELIKE($_[0])) {',
-            $self->_inline_throw_exception( "InvalidArgumentToMethod => ".
+            $self->_inline_throw_exception( InvalidArgumentToMethod =>
                                             'argument                => $_[0],'.
                                             'method_name             => "first_index",'.
                                             'type_of_argument        => "code reference",'.
@@ -32,13 +29,23 @@ sub _inline_check_arguments {
     );
 }
 
-sub _return_value {
+sub _inline_return_value {
     my $self = shift;
     my ($slot_access) = @_;
 
-    return '&List::MoreUtils::first_index($_[0], @{ (' . $slot_access . ') })';
+    return join '',
+        'my @values = @{ (' . $slot_access . ') };',
+        'my $f = $_[0];',
+        'foreach my $i ( 0 .. $#values ) {',
+            'local *_ = \\$values[$i];',
+            'return $i if $f->();',
+        '}',
+        'return -1;';
 }
 
+# Not called, but needed to satisfy the Reader role
+sub _return_value { }
+
 no Moose::Role;
 
 1;
