@@ -1,8 +1,6 @@
 package Moose::Exception::AutoDeRefNeedsArrayRefOrHashRef;
-BEGIN {
-  $Moose::Exception::AutoDeRefNeedsArrayRefOrHashRef::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::AutoDeRefNeedsArrayRefOrHashRef::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::InvalidAttributeOptions';
@@ -12,4 +10,5 @@ sub _build_message {
     "You cannot auto-dereference anything other than a ArrayRef or HashRef on attribute (".$self->attribute_name.")";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
