@@ -1,8 +1,6 @@
 package Moose::Exception::BuilderMethodNotSupportedForInlineAttribute;
-BEGIN {
-  $Moose::Exception::BuilderMethodNotSupportedForInlineAttribute::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::BuilderMethodNotSupportedForInlineAttribute::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Instance', 'Moose::Exception::Role::Class';
@@ -24,4 +22,5 @@ sub _build_message {
     $self->class_name." does not support builder method '". $self->builder ."' for attribute '" . $self->attribute_name . "'";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
