@@ -1,8 +1,6 @@
 package Moose::Exception::CannotCallAnAbstractBaseMethod;
-BEGIN {
-  $Moose::Exception::CannotCallAnAbstractBaseMethod::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CannotCallAnAbstractBaseMethod::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -17,4 +15,5 @@ sub _build_message {
     $self->package_name. " is an abstract base class, you must provide a constructor.";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
