@@ -1,8 +1,6 @@
 package Moose::Exception::CannotCreateMethodAliasLocalMethodIsPresentInClass;
-BEGIN {
-  $Moose::Exception::CannotCreateMethodAliasLocalMethodIsPresentInClass::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CannotCreateMethodAliasLocalMethodIsPresentInClass::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::Role', 'Moose::Exception::Role::Method', 'Moose::Exception::Role::Class';
@@ -17,4 +15,5 @@ sub _build_message {
     "Cannot create a method alias if a local method of the same name exists";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
