@@ -1,8 +1,6 @@
 package Moose::Exception::MustProvideANameForTheAttribute;
-BEGIN {
-  $Moose::Exception::MustProvideANameForTheAttribute::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::MustProvideANameForTheAttribute::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use Moose;
 extends 'Moose::Exception';
 with 'Moose::Exception::Role::ParamsHash';
@@ -17,4 +15,5 @@ sub _build_message {
     "You must provide a name for the attribute";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
