@@ -1,8 +1,6 @@
 package Moose::Exception::CouldNotParseType;
-BEGIN {
-  $Moose::Exception::CouldNotParseType::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Exception::CouldNotParseType::VERSION = '2.1204';
+our $VERSION = '2.2013';
+
 use Moose;
 extends 'Moose::Exception';
 
@@ -28,4 +26,5 @@ sub _build_message {
         . " and str-length=$length)";
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
